V1.0.0(formal)
Simpler DosKill, with the removal of attack address warnings, attack byte packet reduction
The ctypes is not used,So this version does not use administrator mode for attacks
The os is not used,Because it doesn't work
Random timeouts are not used
Generating logs is not supported
Attacking individual pages is not supported
Attack progress is not displayed